Welcome to py-opredflag
=======================

A package written in python with useful scripts for `Operation Red Flag <https://opredflag.com>`_.

**Features:**

- Intuitive Command-Line Interface (CLI)
- Easy-to-use Pythonic design
- Categorical design with dedicated sub-modules for different usages

Getting started
---------------

Is this your first time using the library? This is the place to get started!

- **First steps:** :doc:`installing` | :doc:`quickstart`
- **Examples:** Many examples are available in the :resource:`repository <examples>`.

Getting help
------------

If you're having trouble with something, these resources might help.

..
    - Try the :doc:`faq` first, it's got answers to all common questions.

- Ask us and hang out with us in our :resource:`Discord <discord>` server.
- If you're looking for something specific, try the :ref:`index <genindex>` or :ref:`searching <search>`.
- Report bugs in the :resource:`issue tracker <issues>`.

Manuals
-------

These pages go into great detail about everything the package API can do.

Core API
~~~~~~~~

.. toctree::
  :maxdepth: 1

  api/index.rst

Meta
----

If you're looking for something related to the project itself, it's here.

.. toctree::
  :caption: Meta
  :maxdepth: 1
  :hidden:

  changelog
  version_guarantees

- :doc:`changelog` - The changelog for the library.
- :doc:`version_guarantees` - The version guarantees for the library.
